@@ -97,7 +97,7 @@
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
-#define HAVE_TERMIO_H 1
+/* #undef HAVE_TERMIO_H */
 #define HAVE_TERMCAP_H 1
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
@@ -517,18 +517,18 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 
 /* #undef SO_EXT */
 
-#define MYSQL_VERSION_MAJOR 11
-#define MYSQL_VERSION_MINOR 8
+#define MYSQL_VERSION_MAJOR 12
+#define MYSQL_VERSION_MINOR 2
 #define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.8.2"
+#define PACKAGE_STRING "MySQL Server 12.2.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.8.2"
-#define VERSION "11.8.2"
+#define PACKAGE_VERSION "12.2.2"
+#define VERSION "12.2.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -542,7 +542,6 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 #ifndef EMBEDDED_LIBRARY
 /* #undef WSREP_INTERFACE_VERSION */
 #define WITH_WSREP 1
-#define WSREP_PROC_INFO 1
 #endif
 
 #if !defined(__STDC_FORMAT_MACROS)
